==> illumination_0.1.20090329-1.tar.gz: illumination-0.1.20090329/include/Lum/OS/Manager/KeyboardManager.h <==
#ifndef LUM_OS_MANAGER_KEYBOARDMANAGER_H
#define LUM_OS_MANAGER_KEYBOARDMANAGER_H

/*
  This source is part of the Illumination library
  Copyright (C) 2008  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Private/ImportExport.h>

#include <Lum/OS/Window.h>

#include <Lum/Object.h>

namespace Lum {
  namespace OS {
    namespace Manager {

      class LUMAPI KeyboardManager : public Lum::Base::MsgObject
      {
      protected:
        KeyboardManager();

      public:
        virtual ~KeyboardManager();

        virtual void Shutdown() = 0;

        virtual void OnWindowFocusIn(Window* window) = 0;
        virtual void OnWindowFocusOut(Window* window) = 0;
        virtual void OnFocusChange(Window* window, Lum::Object* oldObject, Lum::Object* newObject) = 0;

        virtual bool HandleEvent(Window* window, OS::Event* event)= 0;
      };
    }
  }
}

#endif

==> illumination_0.1.20100122-1.tar.gz: illumination-0.1.20100122/include/Lum/OS/Manager/KeyboardManager.h <==
#ifndef LUM_OS_MANAGER_KEYBOARDMANAGER_H
#define LUM_OS_MANAGER_KEYBOARDMANAGER_H

/*
  This source is part of the Illumination library
  Copyright (C) 2008  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Private/ImportExport.h>

#include <Lum/OS/Window.h>

#include <Lum/Object.h>

namespace Lum {
  namespace OS {
    namespace Manager {

      class LUMAPI KeyboardManager : public Lum::Base::MsgObject
      {
      protected:
        KeyboardManager();

      public:
        virtual ~KeyboardManager();

        virtual void Shutdown() = 0;

        virtual void OnWindowFocusIn(Window* window) = 0;
        virtual void OnWindowFocusOut(Window* window) = 0;
        virtual void OnFocusChange(Window* window,
                                   Lum::Object* oldObject,
                                   Lum::Object* newObject) = 0;
        virtual void OnMouseClick(Window* window,
                                  Lum::Object* object,
                                  MouseEvent* event) = 0;

        virtual bool HandleEvent(Window* window, Event* event)= 0;
      };
    }
  }
}

#endif
